nbxmpp.auth_nb.NonBlockingBind

Package nbxmpp :: Module auth_nb :: Class NonBlockingBind |
[hide private]
[frames] | no frames]

# Class NonBlockingBind

source code

Bind some JID to the current connection to allow router know of our location. Must be plugged after successful SASL auth

Instance Methods | [hide private]
__init__(self) | source code
plugin(self, owner) Start resource binding, if allowed at this time. Used internally. | source code
FeaturesHandler(self, conn, feats) Determine if server supports resource binding and set some internal attributes accordingly. | source code
plugout(self) Remove Bind handler from owner's dispatcher. Used internally | source code
NonBlockingBind(self, resource=None, on_bound=None) Perform binding. Use provided resource name or random (if not provided). | source code
_on_bound(self, resp) | source code
_on_session(self, resp) | source code
Inherited from `plugin.PlugIn`: `PlugIn`, `PlugOut`

Class Methods | [hide private]
Inherited from `plugin.PlugIn`: `get_instance`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
Overrides: plugin.PlugIn.__init__

### plugin(self, owner) | source code
Start resource binding, if allowed at this time. Used internally.

### FeaturesHandler(self, conn, feats) | source code
Determine if server supports resource binding and set some internal attributes accordingly. It also checks if server supports stream management

### plugout(self) | source code
Remove Bind handler from owner's dispatcher. Used internally

### NonBlockingBind(self, resource=None, on_bound=None) | source code
Perform binding. Use provided resource name or random (if not provided).

### _on_bound(self, resp) | source code

### _on_session(self, resp) | source code